linux-6.6.117-sparky-lts66 for Debian
------------------------------------

<This file describes information about the source package, see Debian policy
manual section 4.14. You WILL either need to modify or delete this file.>



 -- pavroo <pavroo@onet.eu>  Mon, 24 Nov 2025 17:19:48 +0100
